==> qtjambi-webenginecore-6.2.2-sources.jar: io/qt/webengine/core/QWebEngineNewWindowRequest.java <==
package io.qt.webengine.core;


/**
 * <p>A utility type for the QWebEnginePage::newWindowRequested() signal</p>
 * <p>Java wrapper for Qt class <a href="https://doc.qt.io/qt/qwebenginenewwindowrequest.html">QWebEngineNewWindowRequest</a></p>
 */
public final class QWebEngineNewWindowRequest extends io.qt.core.QObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QWebEngineNewWindowRequest.class);
    
    /**
     * <p>Java wrapper for Qt enum <a href="https://doc.qt.io/qt/qwebenginenewwindowrequest.html#DestinationType-enum">QWebEngineNewWindowRequest::DestinationType</a></p>
     */
    public enum DestinationType implements io.qt.QtEnumerator {
        InNewWindow(0),
        InNewTab(1),
        InNewDialog(2),
        InNewBackgroundTab(3);

        private DestinationType(int value) {
            this.value = value;
        }

        /**
         * {@inheritDoc}
         */
        public int value() {
            return value;
        }

        /**
         * Returns the corresponding enum entry for the given value.
         * @param value
         * @return enum entry
         */
        public static DestinationType resolve(int value) {
            switch (value) {
            case 0: return InNewWindow;
            case 1: return InNewTab;
            case 2: return InNewDialog;
            case 3: return InNewBackgroundTab;
            default: throw new io.qt.QNoSuchEnumValueException(value);
            }
        }


        private final int value;
    }
    
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qwebenginenewwindowrequest.html#destination-prop">QWebEngineNewWindowRequest::destination()const</a></p>
     */
    @io.qt.QtPropertyReader(name="destination")
    @io.qt.QtPropertyConstant
    @io.qt.QtUninvokable
    public final io.qt.webengine.core.QWebEngineNewWindowRequest.DestinationType destination(){
        return io.qt.webengine.core.QWebEngineNewWindowRequest.DestinationType.resolve(destination_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this)));
    }
    
    @io.qt.QtUninvokable
    private native int destination_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qwebenginenewwindowrequest.html#userInitiated-prop">QWebEngineNewWindowRequest::isUserInitiated()const</a></p>
     */
    @io.qt.QtPropertyReader(name="userInitiated")
    @io.qt.QtPropertyConstant
    @io.qt.QtUninvokable
    public final boolean isUserInitiated(){
        return isUserInitiated_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean isUserInitiated_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qwebenginenewwindowrequest.html#openIn">QWebEngineNewWindowRequest::openIn(QWebEnginePage*)</a></p>
     */
    @io.qt.QtUninvokable
    public final void openIn(io.qt.webengine.core.QWebEnginePage arg__1){
        openIn_native_QWebEnginePage_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(arg__1));
    }
    
    @io.qt.QtUninvokable
    private native void openIn_native_QWebEnginePage_ptr(long __this__nativeId, long arg__1);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qwebenginenewwindowrequest.html#requestedGeometry-prop">QWebEngineNewWindowRequest::requestedGeometry()const</a></p>
     */
    @io.qt.QtPropertyReader(name="requestedGeometry")
    @io.qt.QtPropertyConstant
    @io.qt.QtUninvokable
    public final io.qt.core.QRect requestedGeometry(){
        return requestedGeometry_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QRect requestedGeometry_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qwebenginenewwindowrequest.html#requestedUrl-prop">QWebEngineNewWindowRequest::requestedUrl()const</a></p>
     */
    @io.qt.QtPropertyReader(name="requestedUrl")
    @io.qt.QtPropertyConstant
    @io.qt.QtUninvokable
    public final io.qt.core.QUrl requestedUrl(){
        return requestedUrl_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QUrl requestedUrl_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QWebEngineNewWindowRequest(QPrivateConstructor p) { super(p); } 
    
}

==> qtjambi-webenginecore-6.2.10-sources.jar: io/qt/webengine/core/QWebEngineNewWindowRequest.java <==
package io.qt.webengine.core;


/**
 * <p>A utility type for the QWebEnginePage::newWindowRequested() signal</p>
 * <p>Java wrapper for Qt's class <a href="https://doc.qt.io/qt/qwebenginenewwindowrequest.html">QWebEngineNewWindowRequest</a></p>
 */
public final class QWebEngineNewWindowRequest extends io.qt.core.QObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QWebEngineNewWindowRequest.class);
    
    /**
     * <p>Java wrapper for Qt enum <a href="https://doc.qt.io/qt/qwebenginenewwindowrequest.html#DestinationType-enum">QWebEngineNewWindowRequest::DestinationType</a></p>
     */
    public enum DestinationType implements io.qt.QtEnumerator {
        InNewWindow(0),
        InNewTab(1),
        InNewDialog(2),
        InNewBackgroundTab(3);

        static {
            QtJambi_LibraryUtilities.initialize();
        }

        private DestinationType(int value) {
            this.value = value;
        }

        /**
         * {@inheritDoc}
         */
        public int value() {
            return value;
        }

        /**
         * Returns the corresponding enum entry for the given value.
         * @param value
         * @return enum entry
         */
        public static DestinationType resolve(int value) {
            switch (value) {
            case 0: return InNewWindow;
            case 1: return InNewTab;
            case 2: return InNewDialog;
            case 3: return InNewBackgroundTab;
            default: throw new io.qt.QNoSuchEnumValueException(value);
            }
        }


        private final int value;
    }
    
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qwebenginenewwindowrequest.html#destination-prop">QWebEngineNewWindowRequest::destination()const</a></p>
     */
    @io.qt.QtPropertyReader(name="destination")
    @io.qt.QtPropertyConstant
    @io.qt.QtUninvokable
    public final io.qt.webengine.core.QWebEngineNewWindowRequest.DestinationType destination(){
        return io.qt.webengine.core.QWebEngineNewWindowRequest.DestinationType.resolve(destination_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this)));
    }
    
    @io.qt.QtUninvokable
    private native int destination_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qwebenginenewwindowrequest.html#userInitiated-prop">QWebEngineNewWindowRequest::isUserInitiated()const</a></p>
     */
    @io.qt.QtPropertyReader(name="userInitiated")
    @io.qt.QtPropertyConstant
    @io.qt.QtUninvokable
    public final boolean isUserInitiated(){
        return isUserInitiated_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean isUserInitiated_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qwebenginenewwindowrequest.html#openIn">QWebEngineNewWindowRequest::openIn(QWebEnginePage*)</a></p>
     */
    @io.qt.QtUninvokable
    public final void openIn(io.qt.webengine.core.QWebEnginePage arg__1){
        openIn_native_QWebEnginePage_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(arg__1));
    }
    
    @io.qt.QtUninvokable
    private native void openIn_native_QWebEnginePage_ptr(long __this__nativeId, long arg__1);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qwebenginenewwindowrequest.html#requestedGeometry-prop">QWebEngineNewWindowRequest::requestedGeometry()const</a></p>
     */
    @io.qt.QtPropertyReader(name="requestedGeometry")
    @io.qt.QtPropertyConstant
    @io.qt.QtUninvokable
    public final io.qt.core.QRect requestedGeometry(){
        return requestedGeometry_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QRect requestedGeometry_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qwebenginenewwindowrequest.html#requestedUrl-prop">QWebEngineNewWindowRequest::requestedUrl()const</a></p>
     */
    @io.qt.QtPropertyReader(name="requestedUrl")
    @io.qt.QtPropertyConstant
    @io.qt.QtUninvokable
    public final io.qt.core.QUrl requestedUrl(){
        return requestedUrl_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QUrl requestedUrl_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QWebEngineNewWindowRequest(QPrivateConstructor p) { super(p); } 
    
}
